@@ -1,5 +1,3 @@
-
-
 #    Copyright 2012 Urban Airship
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,6 +23,7 @@ import plistlib
 import os
 import re
 import support
+import errno
 
 from collections import namedtuple
 from xml.parsers.expat import ExpatError
@@ -66,7 +65,7 @@ def clean():
 
     if os.path.exists(entitlement_plist_path):
         log.info("Removing old entitlements plist file at %s",
-            entitlement_plist_path)
+                 entitlement_plist_path)
         os.remove(entitlement_plist_path)
 
 
@@ -101,6 +100,7 @@ def get_verification_request(ua_verification_information):
     key, secret = ua_verification_information.key_secret()
     return support.get_base_verification_request(appKey=key, appSecret=secret)
 
+
 def make_request_against_api(request):
     """Make a request against the UA API
 
@@ -120,14 +120,23 @@ def make_request_against_api(request):
     if response.error is not None:
 
         if response.error.code == 401:
-            support.fail_log_message("Incorrect app key and secret",
-                APP_KEY_SECRET_INCORRECT_401)
+            log.error(APP_KEY_SECRET_INCORRECT_401)
 
         if response.error.code == 403:
-            support.fail_log_message("Incorrect app secret",
-                APP_KEY_SECRET_INCORRECT_403)
+            log.error(APP_KEY_SECRET_INCORRECT_403)
+
     return response
 
+DEPRECATED_PLIST_CONVERT_MSG = """
+Plist parsing error, attempting to convert plist from old style plist
+to XML plist
+"""
+
+AIRSHIP_CONFIG_MISSING_MSG = """
+Error opening the plist at path %s, did you forget to
+add it to the bundle?
+"""
+
 
 def extract_airship_config_from_app(application_path):
     """ Attempts to read the AirshipConfig.plist out of th app bundle
@@ -140,25 +149,26 @@ def extract_airship_config_from_app(application_path):
     :returns: AirshipConfig.plist as a dictionary
     :rtype: dict
     """
-    airship_config_plist = support.get_value_from_config(support.AIRSHIP_CONFIG_PLIST)
+    airship_config_plist =\
+        support.get_value_from_config(support.AIRSHIP_CONFIG_PLIST)
+
     path_to_plist = os.path.join(application_path, airship_config_plist)
 
     try:
         plist = plistlib.readPlist(path_to_plist)
 
     except IOError as error:
-        log.error("""Error opening the plist at path %s, did you forget to at
-        it to the bundle? Error %s""", path_to_plist, error.message)
-        return None
-    # TODO add example about fixing deprecated plist
+        if error.errno == errno.ENOENT:
+            log.error(AIRSHIP_CONFIG_MISSING_MSG)
+            return None
+
     except ExpatError:
-        support.warn_log_message("Plist parsing error, attempting to convert plist")
+        log.info(DEPRECATED_PLIST_CONVERT_MSG)
         plist = convert_deprecated_plist_at_path(path_to_plist)
         if plist is None:
             return None
         else:
-            support.warn_log_message("Plist conversion successful, change to non deprecated "
-                      "plist format to avoid this error.")
+            log.info("Plist conversion successful.")
 
     log.debug("AirshipConfig.plist:%s", plist)
     return plist
@@ -179,7 +189,8 @@ def convert_deprecated_plist_at_path(path_to_plist):
     try:
         subprocess.check_call(plutil_command)
     except subprocess.CalledProcessError as error:
-        log.error("plutil conversion failed with error %s", error.message)
+        log.error("plutil conversion failed with error code %s" %
+                  str(error.errno))
         return
 
     try:
@@ -190,6 +201,33 @@ def convert_deprecated_plist_at_path(path_to_plist):
         return
     return plist
 
+CODESIGN_PATH_ERROR = """
+Check path to codesign tool with `which codesign`
+and ensure your shell $PATH contains that path, you may
+need to install the Command Line Tools
+"""
+
+CODESIGN_BAD_DIR_ERROR = """
+Check the path to the directory and verify that it is an iOS Application
+bundle.
+"""
+
+CODESIGN_NO_DIR_ERROR = """
+Codesign verification failed, check the path to the app for errors
+Path {path}
+"""
+
+CODESIGN_SUBPROC_ERROR = """
+Error in codesign system call, please run with -d flag and email the diagnostic
+output to support@urbanairship.com
+"""
+
+CODESIGN_TOOL_PATH_ERROR = """
+The codesign tool doesn't appear to be on the shell path. Check it with
+`which codesign`, and change the path. If you have further issues, please
+run the tool with the -d flag and email the diagnostic output to
+support@urbanairship.com
+"""
 
 
 def execute_codesign_system_call(application_path):
@@ -197,8 +235,9 @@ def execute_codesign_system_call(application_path):
 
     The other part of the output is written to the /tmp dir in the form of
     a plist. If there is a CalledProcessError, an attempt to check for the
-    existence of the codesign tool by calling `which codesign`, and an message
-    is logged.
+    existence of the codesign tool by calling `which codesign`, followed by
+    a check to see if the directory exists. If the directory exists, but the
+    codesign tool fails, it is assumed that it is not an app bundle.
 
     :param application_path: Path to the .app application package
     :type key: str
@@ -209,25 +248,23 @@ def execute_codesign_system_call(application_path):
     command = codesign_system_call_args(application_path)
     try:
         subprocess.check_call(command)
-
     except subprocess.CalledProcessError:
-        log.error("Call process error returned from codesign system call")
+        # If the codesign tool is on the path, then directory must be off
         if not os.path.exists(application_path):
-            log.error("""Codesign verification failed, check the path to the
-             app for errors Path:%s""", application_path)
+            log.error(CODESIGN_NO_DIR_ERROR.format(path=application_path))
             return False
         else:
-            # Check the edge case where codesign is not on the path
-            try:
-                subprocess.check_call(["which", "codesign"])
-                return False
-            except subprocess.CalledProcessError:
-                log.error(textwrap.dedent(
-                """Check path to codesign tool with `which codesign`
-                and ensure your shell $PATH contains that path, you may
-                need to install the Command Line Tools"""))
+            log.error(CODESIGN_BAD_DIR_ERROR)
             return False
 
+    except OSError as os_error:
+        if os_error.errno == errno.ENOENT:
+            log.error(CODESIGN_TOOL_PATH_ERROR)
+            return False
+        else:
+            log.error(CODESIGN_SUBPROC_ERROR)
+            raise
+
     return True
 
 
@@ -296,14 +333,15 @@ Secret:{app_secret}
 """
 
 # key_secret fail message
-AIRSHIP_CONFIG_PARSE_FAIL ="""
+AIRSHIP_CONFIG_PARSE_FAIL = """
 AirshipConfig.plist does not contain a bool or
 string value for the APP_STORE_OR_AD_HOC key. Use PlistBuddy,
 plutil, or Xcode to check the plist values"""
 
 # check_bundle_id fail message
 CHECK_BUNDLE_ID_FAIL = """Application bundle id {app_bundle} does not match
-the bundle id configured on Urban Airship {ua_bundle}. Check the configuration"""
+the bundle id configured on Urban Airship {ua_bundle}. Check the configuration
+"""
 
 # check_aps_environment fail message
 APS_ENVIRONMENT_KEY_FAIL = """
@@ -365,8 +403,7 @@ class VerificationInformation(object):
                     is_production = True
             else:
                 # If not a bool or string, quit
-                support.fail_log_message("AirshipConfig.plist not readable",
-                    AIRSHIP_CONFIG_PARSE_FAIL)
+                log.error(AIRSHIP_CONFIG_PARSE_FAIL)
                 sys.exit(EXIT_FAILURE)
         return is_production
 
@@ -382,7 +419,6 @@ class VerificationInformation(object):
         :rtype: tuple
         """
 
-
         is_production = self.airship_config_is_production()
 
         if is_production:
@@ -405,30 +441,24 @@ class VerificationInformation(object):
         :returns: True if the key exists, false otherwise
         :rtype: bool
         """
-
         try:
             full_bundle_id = self.entitlements_plist[ENTITLE_APP_ID_KEY]
         except KeyError:
-            # TODO better error message
-            support.fail_log_message("""Entitlements plist does not have a app id, this
-            might be a bug in the script.""",
-                """Email support@urbanairship.com""")
+            log.error("Key error")
             return False
+
         try:
             self.entitlements_plist[ENTITLE_APS_ENV_KEY]
         except KeyError:
-            msg = "No APS environment key"
-            remedial = APS_ENVIRONMENT_KEY_FAIL.format(
-                bundle_id=full_bundle_id)
-            support.fail_log_message(msg, remedial)
+            remedial = APS_ENVIRONMENT_KEY_FAIL.format(bundle_id=full_bundle_id)
+            log.error(remedial)
             return False
+
         msg = "Environment is set properly for bundle id {0}".format(
             full_bundle_id)
-        support.pass_log_message(msg)
+        log.info(msg)
         return True
 
-
-
     def check_apns_server(self, ua_verification_response):
         """ Check the production/development server in entitlements
 
@@ -466,20 +496,25 @@ class VerificationInformation(object):
 
         # Line up the servers
         if not ua_aps_configuration == aps_environment == aps_env_description:
-            msg = "APS Environments don't match"
-            # TODO fix these key/values up, so they are no more numbers or repetition
+            # TODO fix these key/values up, so they are no more numbers or
+            # repetition, I mean, this is just bad.
             remedial = REMEDIAL_APS_ACTION.format(aps_env_description,
-                aps_environment, ua_aps_configuration,adhoc_or_prod,
-                aps_environment, ua_aps_configuration, app_key=app_key,
-                app_secret=app_secret, ua_server=ua_aps_configuration,
-                entitle_server=aps_env_description)
-            support.fail_log_message(msg, remedial)
+                                                  aps_environment,
+                                                  ua_aps_configuration,
+                                                  adhoc_or_prod,
+                                                  aps_environment,
+                                                  ua_aps_configuration,
+                                                  app_key=app_key,
+                                                  app_secret=app_secret,
+                                                  ua_server=ua_aps_configuration,
+                                                  entitle_server=aps_env_description)
+            log.error(remedial)
             return False
+
         msg = "\nUrban Airship server is configured for: {0}\n".format(
             ua_aps_configuration)
-
         msg += "App is configured for: {0}".format(aps_environment)
-        support.pass_log_message(msg)
+        log.info(msg)
         return True
 
     def check_bundle_id(self, ua_verification_response):
@@ -506,13 +541,13 @@ class VerificationInformation(object):
         log.info("Urban Airship Configured App Bundle id is: %s", ua_bundle_id)
 
         if entitlements_bundle_id == ua_bundle_id:
-            support.pass_log_message("Bundle id is correct")
+            log.info("Bundle id is correct")
             return True
         else:
-           remedial = CHECK_BUNDLE_ID_FAIL.format(
-               app_bundle=entitlements_bundle_id, ua_bundle=ua_bundle_id)
-           support.fail_log_message("Bundle id is incorrect", remedial)
-           return False
+            remedial = CHECK_BUNDLE_ID_FAIL.format(
+                app_bundle=entitlements_bundle_id, ua_bundle=ua_bundle_id)
+            log.error(remedial)
+            return False
 
     def log_diagnostic_information(self):
         """Log out entitlements/config information for diagnostics
